@@ -56,7 +56,8 @@ typedef enum
 	RARLABS,
 	GNAUNRAR,
 	UNZIP,
-	P7ZIP
+	P7ZIP,
+	TAR
 } ComicBookDecompressType;
 
 typedef struct _ComicsDocumentClass ComicsDocumentClass;
@@ -116,6 +117,9 @@ static const ComicBookDecompressCommand command_usage_def[] = {
 
         /* 7zip */
 	{NULL               , "%s l -- %s"     , "%s x -y %s -o%s", FALSE, OFFSET_7Z},
+
+        /* tar */
+	{"%s -xOf"          , "%s -tf %s"      , NULL             , FALSE, NO_OFFSET}
 };
 
 static GSList*    get_supported_image_extensions (void);
@@ -311,8 +315,8 @@ comics_check_decompress_command	(gchar          *mime_type,
 	/* FIXME, use proper cbr/cbz mime types once they're
 	 * included in shared-mime-info */
 	
-	if (g_content_type_is_a (mime_type, "application/x-cbr") ||
-	    g_content_type_is_a (mime_type, "application/x-rar")) {
+	if (!strcmp (mime_type, "application/x-cbr") ||
+	    !strcmp (mime_type, "application/x-rar")) {
 	        /* The RARLAB provides a no-charge proprietary (freeware) 
 	        * decompress-only client for Linux called unrar. Another 
 		* option is a GPLv2-licensed command-line tool developed by 
@@ -360,8 +364,15 @@ comics_check_decompress_command	(gchar          *mime_type,
 			comics_document->command_usage = GNAUNRAR;
 			return TRUE;
 		}
-	} else if (g_content_type_is_a (mime_type, "application/x-cbz") ||
-		   g_content_type_is_a (mime_type, "application/zip")) {
+		comics_document->selected_command =
+				g_find_program_in_path ("bsdtar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
+
+	} else if (!strcmp (mime_type, "application/x-cbz") ||
+		   !strcmp (mime_type, "application/zip")) {
 		/* InfoZIP's unzip program */
 		comics_document->selected_command = 
 				g_find_program_in_path ("unzip");
@@ -385,9 +396,15 @@ comics_check_decompress_command	(gchar          *mime_type,
 			comics_document->command_usage = P7ZIP;
 			return TRUE;
 		}
+		comics_document->selected_command =
+				g_find_program_in_path ("bsdtar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
 
-	} else if (g_content_type_is_a (mime_type, "application/x-cb7") ||
-		   g_content_type_is_a (mime_type, "application/x-7z-compressed")) {
+	} else if (!strcmp (mime_type, "application/x-cb7") ||
+		   !strcmp (mime_type, "application/x-7z-compressed")) {
 		/* 7zr, 7za and 7z are the commands from the p7zip project able 
 		 * to decompress .7z files */ 
 		comics_document->selected_command =
@@ -408,6 +425,27 @@ comics_check_decompress_command	(gchar          *mime_type,
 			comics_document->command_usage = P7ZIP;
 			return TRUE;
 		}
+		comics_document->selected_command =
+				g_find_program_in_path ("bsdtar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
+	} else if (!strcmp (mime_type, "application/x-cbt") ||
+		   !strcmp (mime_type, "application/x-tar")) {
+		/* tar utility (Tape ARchive) */
+		comics_document->selected_command =
+				g_find_program_in_path ("tar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
+		comics_document->selected_command =
+				g_find_program_in_path ("bsdtar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
 	} else {
 		g_set_error (error,
 			     EV_DOCUMENT_ERROR,
