@@ -48,9 +48,6 @@ struct _EvSidebarAnnotationsClass {
 
 	void    (* annot_activated)     (EvSidebarAnnotations *sidebar_annots,
 					 EvMapping            *mapping);
-	void    (* begin_annot_add)     (EvSidebarAnnotations *sidebar_annots,
-					 EvAnnotationType      annot_type);
-	void    (* annot_add_cancelled) (EvSidebarAnnotations *sidebar_annots);
 };
 
 GType      ev_sidebar_annotations_get_type      (void) G_GNUC_CONST;
